@@ -41,4 +41,4 @@ for data in spyglass.streaming_cmd('chart',
                                    json=None,
                                    start_date=None,
                                    end_date=args.end_date):
-    print data
+    print(data)
